@@ -7,11 +7,11 @@ package org.gcube.portal.databook.shared;
  */
 public enum ShowUserStatisticAction {
 
-	POSTS_MADE_BY_USER("Recent Posts"),
-	LIKES_MADE_BY_USER("Recent Likes Made"),
-	COMMENTS_MADE_BY_USER("Recent Comments Made"),
-	LIKES_GOT_BY_USER("Recent Likes Got"),
-	COMMENTS_GOT_BY_USER("Recent Comments Got");
+	POSTS_MADE_BY_USER("Your recent posts"),
+	LIKES_MADE_BY_USER("Posts you liked"),
+	COMMENTS_MADE_BY_USER("Posts you commented"),
+	LIKES_GOT_BY_USER("Likes to your posts"),
+	COMMENTS_GOT_BY_USER("Replies to your posts");
 	
 	private final String actionHumanFriendly;
 	
