@@ -64,7 +64,7 @@ public class LiferayGroupManager implements GroupManager {
 		if (g != null) {
 			long logoId = LayoutSetLocalServiceUtil.getLayoutSet(g.getGroupId(), true).getLogoId();
 			if (isVRE(g.getGroupId())) {
-				return new GCubeGroup(g.getGroupId(), g.getParentGroupId(), g.getName(), g.getDescription(), g.getFriendlyURL(), logoId, null, getMappedGroupMembershipType(g.getType()));
+				return new GCubeGroup(g.getGroupId(), g.getParentGroupId(), g.getName(), g.getDescription(), g.getFriendlyURL(), logoId, UserLocalServiceUtil.getGroupUsersCount(g.getGroupId()), null, getMappedGroupMembershipType(g.getType()));
 			}
 			else if (isVO(g.getGroupId())) {
 				List<GCubeGroup> vres = new ArrayList<GCubeGroup>();
@@ -72,13 +72,13 @@ public class LiferayGroupManager implements GroupManager {
 				for (Group vre : VREs) {
 					vres.add(mapLRGroup(vre));
 				}
-				return new GCubeGroup(g.getGroupId(), g.getParentGroupId(), g.getName(), g.getDescription(), g.getFriendlyURL(), logoId, vres, getMappedGroupMembershipType(g.getType()));
+				return new GCubeGroup(g.getGroupId(), g.getParentGroupId(), g.getName(), g.getDescription(), g.getFriendlyURL(), logoId, UserLocalServiceUtil.getGroupUsersCount(g.getGroupId()), vres, getMappedGroupMembershipType(g.getType()));
 			} else if (isRootVO(g.getGroupId())) {
 				List<GCubeGroup> vos = new ArrayList<GCubeGroup>();
 				List<Group> children = g.getChildren(true);
 				for (Group vo : children) 
 					vos.add(mapLRGroup(vo));
-				return new GCubeGroup(g.getGroupId(), -1, g.getName(), g.getDescription(), g.getFriendlyURL(), logoId, vos, getMappedGroupMembershipType(g.getType()));
+				return new GCubeGroup(g.getGroupId(), -1, g.getName(), g.getDescription(), g.getFriendlyURL(), logoId, UserLocalServiceUtil.getGroupUsersCount(g.getGroupId()) ,vos, getMappedGroupMembershipType(g.getType()));
 			} else{
 				_log.warn("This groupId does not correspond to a VO ora VRE");
 				return null;
