@@ -11,15 +11,10 @@ import org.apache.http.auth.AuthScope;
 import org.apache.http.auth.UsernamePasswordCredentials;
 import org.apache.http.client.AuthCache;
 import org.apache.http.client.CredentialsProvider;
-import org.apache.http.client.methods.CloseableHttpResponse;
-import org.apache.http.client.methods.HttpGet;
 import org.apache.http.client.protocol.HttpClientContext;
 import org.apache.http.impl.auth.BasicScheme;
 import org.apache.http.impl.client.BasicAuthCache;
 import org.apache.http.impl.client.BasicCredentialsProvider;
-import org.apache.http.impl.client.CloseableHttpClient;
-import org.apache.http.impl.client.HttpClients;
-import org.apache.http.util.EntityUtils;
 import org.gcube.vomanagement.usermanagement.GroupManager;
 import org.gcube.vomanagement.usermanagement.exception.GroupRetrievalFault;
 import org.gcube.vomanagement.usermanagement.exception.UserManagementNameException;
@@ -27,6 +22,7 @@ import org.gcube.vomanagement.usermanagement.exception.UserManagementPortalExcep
 import org.gcube.vomanagement.usermanagement.exception.UserManagementSystemException;
 import org.gcube.vomanagement.usermanagement.exception.UserRetrievalFault;
 import org.gcube.vomanagement.usermanagement.exception.VirtualGroupNotExistingException;
+import org.gcube.vomanagement.usermanagement.impl.ws.utils.HttpUtils;
 import org.gcube.vomanagement.usermanagement.model.CustomAttributeKeys;
 import org.gcube.vomanagement.usermanagement.model.GCubeGroup;
 import org.gcube.vomanagement.usermanagement.model.GCubeRole;
@@ -105,7 +101,7 @@ public class LiferayWSGroupManager implements GroupManager {
 	 */
 	private void retrieveCompanyId() throws Exception {
 
-		String json = executeHTTPGETRequest(API_BASE_URL + GET_COMPANY_ID, credsProvider, localContext, target);
+		String json = HttpUtils.executeHTTPGETRequest(API_BASE_URL + GET_COMPANY_ID, credsProvider, localContext, target);
 
 		if(json != null){
 			JSONParser parser = new JSONParser();
@@ -117,36 +113,6 @@ public class LiferayWSGroupManager implements GroupManager {
 
 	}
 
-	/**
-	 * Execute an http GET request and returns the JSON response
-	 * @param requestPath
-	 * @return a JSON string on success, null otherwise
-	 */
-	private static String executeHTTPGETRequest(String requestPath, CredentialsProvider credsProvider, HttpClientContext localContext, HttpHost target){
-
-		try{
-			CloseableHttpClient httpclient = HttpClients.custom()
-					.setDefaultCredentialsProvider(credsProvider).build();
-
-			HttpGet httpget = new HttpGet(requestPath);
-
-			logger.debug("Executing request " + httpget.getRequestLine() + " to target " + target);
-			CloseableHttpResponse response = httpclient.execute(target, httpget, localContext);
-			try {
-				String result = EntityUtils.toString(response.getEntity());
-				logger.debug("Request result is " + result);
-				return result;
-			} finally {
-				response.close();
-			}
-		}catch(Exception e){
-			logger.error("Exception while performing GET request", e);
-		}
-
-		return null;
-
-	}
-
 	/**
 	 * Map a json object representing a group to a GCubeGroup object
 	 * @param jsonGroup
@@ -165,7 +131,10 @@ public class LiferayWSGroupManager implements GroupManager {
 				long logoId = 0; // TODO
 				long groupId = (long)jsonGroupObject.get("groupId");
 
-				if (isVRE(groupId)) {
+				// faster way to determine if it is a VRE or a VO or the ROOT Vo
+				String threePath = (String)jsonGroupObject.get("treePath");
+
+				if (isVREByTreePath(threePath)) {
 					logger.debug("********** IS VRE");
 					return new GCubeGroup(
 							groupId, 
@@ -177,7 +146,7 @@ public class LiferayWSGroupManager implements GroupManager {
 							null, 
 							getMappedGroupMembershipType(((Long)jsonGroupObject.get("type")).intValue()));
 				}
-				else if (isVO(groupId)) {
+				else if (isVOByTreePath(threePath)) {
 					logger.debug("********** IS VO");
 					List<GCubeGroup> vres = new ArrayList<GCubeGroup>();
 					List<String> vreInJson = getChildren(groupId);
@@ -194,7 +163,7 @@ public class LiferayWSGroupManager implements GroupManager {
 							logoId, 
 							vres, 
 							getMappedGroupMembershipType(((Long)jsonGroupObject.get("type")).intValue()));
-				} else if (isRootVO(groupId)) {
+				} else if (isRootVOByTreePath(threePath)) {
 					logger.debug("********** IS ROOT VO");
 					List<GCubeGroup> vos = new ArrayList<GCubeGroup>();
 					List<String> vosInJson = getChildren(groupId);
@@ -222,6 +191,53 @@ public class LiferayWSGroupManager implements GroupManager {
 		return null;
 	}
 
+	private boolean isVREByTreePath(String threePath) throws Exception {
+		// faster way to determine if it is a VRE or a VO
+		if(threePath == null || threePath.isEmpty())
+			throw new Exception("threePath is missing");
+		return threePath.split("/").length == 4; // e.g. for a VRE is  /21654/21657/21660/ (4)
+	}
+
+	private boolean isVOByTreePath(String threePath) throws Exception {
+		if(threePath == null || threePath.isEmpty())
+			throw new Exception("threePath is missing");
+		return threePath.split("/").length == 3; // e.g. for a VO is  /21654/21657/ (3)
+	}
+
+
+	private boolean isRootVOByTreePath(String threePath) throws Exception {
+		if(threePath == null || threePath.isEmpty())
+			throw new Exception("threePath is missing");
+		return threePath.split("/").length == 2; // e.g. for a Root VO is  /21654/ (2)
+	}
+
+	/**
+	 * Retrieve the threePath given the groupId of the group
+	 * @param groupId
+	 * @return
+	 */
+	private String getTreePathFromGroup(long groupId){
+
+		try{
+
+			String jsonGroup = 
+					HttpUtils.executeHTTPGETRequest(API_BASE_URL + GET_GROUP_BY_ID.replace("$GROUP_ID", String.valueOf(groupId)), 
+							credsProvider, localContext, target);
+
+			if(jsonGroup != null){
+				JSONParser parser = new JSONParser();
+				JSONObject jsonGroupObject = (JSONObject)parser.parse(jsonGroup);
+				return (String)jsonGroupObject.get("treePath");
+			}else
+				return null;
+
+		}catch(Exception e){
+			logger.error("Failed to retrieve threePath information", e);
+			return null;
+		}
+
+	}
+
 	/**
 	 * Retrieve the group children of the group having  id groupId
 	 * @param groupId
@@ -231,7 +247,7 @@ public class LiferayWSGroupManager implements GroupManager {
 		List<String> jsonChildren = new ArrayList<String>();
 		try{
 			String jsonGroups = 
-					executeHTTPGETRequest(API_BASE_URL + GET_GROUPS_BY_PARENT_ID.replace("$COMPANY_ID", String.valueOf(companyId)).replace("$GROUP_PARENT_ID", String.valueOf(groupId))
+					HttpUtils.executeHTTPGETRequest(API_BASE_URL + GET_GROUPS_BY_PARENT_ID.replace("$COMPANY_ID", String.valueOf(companyId)).replace("$GROUP_PARENT_ID", String.valueOf(groupId))
 							.replace("$SITE", Boolean.toString(true)), 
 							credsProvider, localContext, target);
 
@@ -299,7 +315,7 @@ public class LiferayWSGroupManager implements GroupManager {
 			throws UserManagementSystemException, GroupRetrievalFault {
 		try {
 			String jsonGroup = 
-					executeHTTPGETRequest(API_BASE_URL + GET_GROUP_BY_ID.replace("$GROUP_ID", String.valueOf(groupId)), 
+					HttpUtils.executeHTTPGETRequest(API_BASE_URL + GET_GROUP_BY_ID.replace("$GROUP_ID", String.valueOf(groupId)), 
 							credsProvider, localContext, target);
 			JSONParser parser = new JSONParser();
 			JSONObject obj = (JSONObject)parser.parse(jsonGroup);
@@ -315,7 +331,7 @@ public class LiferayWSGroupManager implements GroupManager {
 			throws UserManagementSystemException, GroupRetrievalFault {
 		try{
 			String jsonGroup = 
-					executeHTTPGETRequest(API_BASE_URL + GET_GROUP_BY_NAME.replace("$COMPANY_ID", String.valueOf(companyId)).replace("$GROUP_NAME", groupName), 
+					HttpUtils.executeHTTPGETRequest(API_BASE_URL + GET_GROUP_BY_NAME.replace("$COMPANY_ID", String.valueOf(companyId)).replace("$GROUP_NAME", groupName), 
 							credsProvider, localContext, target);
 
 			if(jsonGroup != null){
@@ -336,7 +352,7 @@ public class LiferayWSGroupManager implements GroupManager {
 			throws UserManagementSystemException, GroupRetrievalFault {
 		try{
 			String jsonGroup = 
-					executeHTTPGETRequest(API_BASE_URL + GET_GROUP_BY_ID.replace("$GROUP_ID", String.valueOf(groupId)), 
+					HttpUtils.executeHTTPGETRequest(API_BASE_URL + GET_GROUP_BY_ID.replace("$GROUP_ID", String.valueOf(groupId)), 
 							credsProvider, localContext, target);
 
 			if(jsonGroup != null){
@@ -365,7 +381,7 @@ public class LiferayWSGroupManager implements GroupManager {
 		try {
 
 			String jsonCustomFields = 
-					executeHTTPGETRequest(API_BASE_URL + GET_GROUP_CUSTOM_FIELDS.replace("$COMPANY_ID", String.valueOf(companyId)).replace("$CUSTOM_KEY", CustomAttributeKeys.VIRTUAL_GROUP.getKeyName()).replace("$GROUP_ID", String.valueOf(actualGroupId)), 
+					HttpUtils.executeHTTPGETRequest(API_BASE_URL + GET_GROUP_CUSTOM_FIELDS.replace("$COMPANY_ID", String.valueOf(companyId)).replace("$CUSTOM_KEY", CustomAttributeKeys.VIRTUAL_GROUP.getKeyName()).replace("$GROUP_ID", String.valueOf(actualGroupId)), 
 							credsProvider, localContext, target);
 
 			if(jsonCustomFields != null){
@@ -475,18 +491,19 @@ public class LiferayWSGroupManager implements GroupManager {
 			throws UserManagementSystemException, GroupRetrievalFault {
 		try {
 			GCubeGroup group = getGroup(groupId);
-			if (isVRE(groupId)){
+			String treePath = getTreePathFromGroup(group.getGroupId());
+			if (isVREByTreePath(treePath)){
 				long voId = group.getParentGroupId();
 				GCubeGroup voGroup = getGroup(voId);
 				long rootVoId = voGroup.getParentGroupId();
 				String rootGroupName = getGroup(rootVoId).getGroupName();
 				return "/" + rootGroupName + "/" + voGroup.getGroupName() + "/" + group.getGroupName();
 			}
-			if (isVO(groupId)){
+			if (isVOByTreePath(treePath)){
 				String rootVoName = getGroup(group.getParentGroupId()).getGroupName();
 				return "/" + rootVoName + "/" + group.getGroupName();
 			}
-			if (isRootVO(groupId)) 
+			if (isRootVOByTreePath(treePath)) 
 				return "/"+group.getGroupName();
 
 		}catch (Exception e) {
@@ -516,7 +533,7 @@ public class LiferayWSGroupManager implements GroupManager {
 		List<GCubeGroup> toReturn = new ArrayList<GCubeGroup>();
 		try{
 			String jsonGroups = // TODO evaluate the max number of groups to return before, somehow
-					executeHTTPGETRequest(API_BASE_URL + GET_GROUPS_BY_USERID.replace("$USER_ID", String.valueOf(userId)).replace("$MAX_GROUP", String.valueOf(1000)), 
+					HttpUtils.executeHTTPGETRequest(API_BASE_URL + GET_GROUPS_BY_USERID.replace("$USER_ID", String.valueOf(userId)).replace("$MAX_GROUP", String.valueOf(1000)), 
 							credsProvider, localContext, target);
 
 			if(jsonGroups != null){
@@ -534,6 +551,34 @@ public class LiferayWSGroupManager implements GroupManager {
 		return toReturn;
 	}
 
+	@Override
+	public List<GCubeGroup> listVresByUser(long userId)
+			throws UserManagementSystemException, GroupRetrievalFault,
+			UserRetrievalFault {
+		List<GCubeGroup> toReturn = new ArrayList<GCubeGroup>();
+		try{
+			String jsonGroups = // TODO evaluate the max number of groups to return before, somehow
+					HttpUtils.executeHTTPGETRequest(API_BASE_URL + GET_GROUPS_BY_USERID.replace("$USER_ID", String.valueOf(userId)).replace("$MAX_GROUP", String.valueOf(1000)), 
+							credsProvider, localContext, target);
+
+			if(jsonGroups != null){
+				logger.debug("Trying to parse json object");
+				JSONParser parser = new JSONParser();
+				JSONArray array = (JSONArray)parser.parse(jsonGroups);
+				for (int i = 0; i < array.size(); i++) {
+					String threePath = (String)((JSONObject)array.get(i)).get("treePath");
+					if(isVREByTreePath(threePath))
+						toReturn.add(mapLRGroup(((JSONObject)array.get(i)).toJSONString()));	
+				}
+				return toReturn;
+			}
+		}catch(Exception e){
+			logger.error("Error while retrieving the group id, returning -1", e);
+		}
+
+		return null;
+	}
+
 	@Override
 	public Set<GCubeGroup> listGroupsByUserAndSite(long userId,
 			String serverName) throws UserRetrievalFault,
@@ -604,12 +649,11 @@ public class LiferayWSGroupManager implements GroupManager {
 			throws GroupRetrievalFault {
 
 		String result = 
-				executeHTTPGETRequest(API_BASE_URL + GET_GROUP_CUSTOM_FIELDS.replace("$COMPANY_ID", String.valueOf(companyId)).replace("$GROUP_ID", String.valueOf(groupId)).replace("$CUSTOM_KEY", attributeKey), 
+				HttpUtils.executeHTTPGETRequest(API_BASE_URL + GET_GROUP_CUSTOM_FIELDS.replace("$COMPANY_ID", String.valueOf(companyId)).replace("$GROUP_ID", String.valueOf(groupId)).replace("$CUSTOM_KEY", attributeKey), 
 						credsProvider, localContext, target);
 
 		logger.debug("Data is " + result);
 
-
 		return result;
 	}
 
@@ -639,7 +683,7 @@ public class LiferayWSGroupManager implements GroupManager {
 		try{
 
 			String jsonGroups = 
-					executeHTTPGETRequest(API_BASE_URL + GET_GROUPS_BY_PARENT_ID.replace("$COMPANY_ID", String.valueOf(companyId)).replace("$GROUP_PARENT_ID", String.valueOf(0))
+					HttpUtils.executeHTTPGETRequest(API_BASE_URL + GET_GROUPS_BY_PARENT_ID.replace("$COMPANY_ID", String.valueOf(companyId)).replace("$GROUP_PARENT_ID", String.valueOf(0))
 							.replace("$SITE", Boolean.toString(true)), 
 							credsProvider, localContext, target);
 
@@ -672,4 +716,4 @@ public class LiferayWSGroupManager implements GroupManager {
 		return gateways;
 	}
 
-}
+}
\ No newline at end of file
