@@ -13,6 +13,7 @@ public class GCubeGroup implements Serializable {
 	String description;
 	String friendlyURL;
 	long logoId;
+	int userCount;
 	List<GCubeGroup> children;
 	GroupMembershipType membershipType;
 	
@@ -48,6 +49,31 @@ public class GCubeGroup implements Serializable {
 		this.membershipType = membershipType;
 	}
 
+	/**
+	 * @param groupId
+	 * @param parentGroupId
+	 * @param groupName
+	 * @param description
+	 * @param friendlyURL
+	 * @param logoId
+	 * @param userCount
+	 * @param children
+	 * @param membershipType
+	 */
+	public GCubeGroup(long groupId, long parentGroupId, String groupName,
+			String description, String friendlyURL, long logoId, int userCount,
+			List<GCubeGroup> children, GroupMembershipType membershipType) {
+		super();
+		this.groupId = groupId;
+		this.parentGroupId = parentGroupId;
+		this.groupName = groupName;
+		this.description = description;
+		this.friendlyURL = friendlyURL;
+		this.logoId = logoId;
+		this.userCount = userCount;
+		this.children = children;
+		this.membershipType = membershipType;
+	}
 
 	public long getGroupId() {
 		return groupId;
@@ -136,10 +162,20 @@ public class GCubeGroup implements Serializable {
 		this.membershipType = membershipType;
 	}
 
+	public int getUserCount() {
+		return userCount;
+	}
+
+	public void setUserCount(int userCount) {
+		this.userCount = userCount;
+	}
+
 	@Override
 	public String toString() {
-		return "GCubeGroup [groupId=" + groupId + ", parentGroupId=" + parentGroupId + ", groupName=" + groupName
-				+ ", description=" + description + ", friendlyURL=" + friendlyURL + ", logoId=" + logoId + ", children="
+		return "GCubeGroup [groupId=" + groupId + ", parentGroupId="
+				+ parentGroupId + ", groupName=" + groupName + ", description="
+				+ description + ", friendlyURL=" + friendlyURL + ", logoId="
+				+ logoId + ", userCount=" + userCount + ", children="
 				+ children + ", membershipType=" + membershipType + "]";
 	}
 
